@@ -1,7 +1,7 @@
 import pathlib
 import configparser
 
-__version__ = '0.17.2'
+__version__ = '0.17.3'
 
 # Load the configuration settings.
 HERE = pathlib.Path(__file__).parent.resolve()
@@ -47,4 +47,7 @@ from asilib.conjunction import Conjunction
 from asilib.asi.themis import themis, themis_info, themis_skymap
 from asilib.asi.rego import rego, rego_info, rego_skymap
 
-__all__ = ['Imager', 'Conjunction']  # So Sphinx shortens the name. See https://stackoverflow.com/a/66743762
\ No newline at end of file
+__all__ = [
+    'Imager',
+    'Conjunction',
+]  # So Sphinx shortens the name. See https://stackoverflow.com/a/66743762
