@@ -15,11 +15,7 @@ from asilib.io import utils
 
 
 def lla2azel(
-    asi_array_code: str,
-    location_code: str,
-    time: utils._time_type,
-    sat_lla: np.ndarray,
-    force_download: bool = False,
+    asi_array_code: str, location_code: str, time: utils._time_type, sat_lla: np.ndarray
 ) -> Tuple[np.ndarray, np.ndarray]:
     """
     Maps, a satellite's latitude, longitude, and altitude (LLA) coordinates
@@ -42,8 +38,6 @@ def lla2azel(
         with shape (nPosition, 3) where each row is the number of satellite positions
         to map, and the columns correspond to latitude, longitude, and altitude,
         respectively. The altitude is in kilometer units.
-    force_download: bool (optional)
-        If True, download the skymap file even if it already exists.
 
     Returns
     -------
@@ -88,9 +82,7 @@ def lla2azel(
     assert sat_lla.shape[1] == 3, 'sat_lla must have 3 columns.'
 
     # Load the catalog
-    skymap_dict = asilib.io.load.load_skymap(
-        asi_array_code, location_code, time, force_download=force_download
-    )
+    skymap_dict = asilib.io.load.load_skymap(asi_array_code, location_code, time)
 
     sat_azel = np.nan * np.zeros((sat_lla.shape[0], 2))
 
