@@ -1,4 +1,4 @@
-#TODO: Remove when cleaning up Imager
+# TODO: Remove when cleaning up Imager
 import pathlib
 from datetime import datetime, timedelta
 import dateutil.parser
@@ -22,7 +22,7 @@ def load_image(
     location_code: str,
     time: utils._time_type = None,
     time_range: utils._time_range_type = None,
-    force_download: bool = False,
+    redownload: bool = False,
     time_thresh_s: float = 3,
     ignore_missing_data: bool = True,
 ):
@@ -41,7 +41,7 @@ def load_image(
         ISO 8601 standard.
     time_range: list of datetime.datetimes or stings
         Defined the duration of data to download. Must be of length 2.
-    force_download: bool
+    redownload: bool
         If True, download the file even if it already exists. Useful if a prior
         data download was incomplete.
     time_thresh_s: float
@@ -69,13 +69,13 @@ def load_image(
     | asi_array_code = 'THEMIS'
     | location_code = 'ATHA'
     | time = datetime(2008, 3, 9, 9, 18, 0)
-    | image_time, image = asilib.load_image(asi_array_code, location_code, time=time, force_download=False)
+    | image_time, image = asilib.load_image(asi_array_code, location_code, time=time, redownload=False)
     |
     | # Load multiple images
     | asi_array_code = 'REGO'
     | location_code = 'LUCK'
     | time_range = [datetime(2017, 9, 27, 7, 15), datetime(2017, 9, 27, 8, 15)]
-    | image_times, images = asilib.load_image(asi_array_code, location_code, time_range=time_range, force_download=False)
+    | image_times, images = asilib.load_image(asi_array_code, location_code, time_range=time_range, redownload=False)
     """
     if (time is None) and (time_range is None):
         raise AttributeError('Neither time or time_range is specified.')
@@ -87,7 +87,7 @@ def load_image(
             asi_array_code,
             location_code,
             time,
-            force_download=force_download,
+            redownload=redownload,
             time_thresh_s=time_thresh_s,
         )
 
@@ -96,7 +96,7 @@ def load_image(
             asi_array_code,
             location_code,
             time_range,
-            force_download=force_download,
+            redownload=redownload,
             ignore_missing_data=ignore_missing_data,
         )
     else:
@@ -107,7 +107,7 @@ def load_image_generator(
     asi_array_code: str,
     location_code: str,
     time_range: utils._time_range_type,
-    force_download: bool = False,
+    redownload: bool = False,
     ignore_missing_data: bool = True,
 ) -> Tuple[np.ndarray, np.ndarray]:
     """
@@ -127,7 +127,7 @@ def load_image_generator(
         The ASI station code, i.e. ``ATHA``
     time_range: list of datetime.datetimes or stings
         Defined the duration of data to download. Must be of length 2.
-    force_download: bool
+    redownload: bool
         If True, download the file even if it already exists. Useful if a prior
         data download was incomplete.
     ignore_missing_data: bool
@@ -160,9 +160,7 @@ def load_image_generator(
 
     for hour in hours:
         try:
-            cdf_path = _find_img_path(
-                asi_array_code, location_code, hour, force_download=force_download
-            )
+            cdf_path = _find_img_path(asi_array_code, location_code, hour, redownload=redownload)
             cdf_obj = cdflib.CDF(cdf_path)
         except FileNotFoundError:
             if ignore_missing_data:
@@ -173,6 +171,13 @@ def load_image_generator(
         epoch = _get_epoch(cdf_obj, time_key, hour, asi_array_code, location_code)
 
         idx = np.where((epoch >= time_range[0]) & (epoch < time_range[1]))[0]
+        if len(idx) == 0:
+            # This happens occasionally if, for example, time_range[0].minute = 57 while
+            # epoch[-1].minute = 55. Continue to not try to yield an empty file.
+            warnings.warn(
+                f'{asi_array_code}-{location_code}, {hour} UT has no images in the time range.'
+            )
+            continue
         yield epoch[idx], cdf_obj.varget(image_key, startrec=idx[0], endrec=idx[-1])
 
 
@@ -180,7 +185,7 @@ def load_skymap(
     asi_array_code: str,
     location_code: str,
     time: utils._time_type,
-    force_download: bool = False,
+    redownload: bool = False,
 ) -> dict:
     """
     Loads the appropriate THEMIS or REGO skymap file (closest and before ``time``) into memory.
@@ -194,7 +199,7 @@ def load_skymap(
     time: datetime.datetime or str
         The date and time to download of the data. If str, ``time`` must be in the
         ISO 8601 standard.
-    force_download: bool
+    redownload: bool
         If True, download the file even if it already exists. Useful if a prior
         data download was incomplete.
 
@@ -213,10 +218,8 @@ def load_skymap(
     if isinstance(time, str):
         time = dateutil.parser.parse(time)
 
-    if force_download:
-        skymap_paths = download_skymap(
-            asi_array_code.lower(), location_code, force_download=force_download
-        )
+    if redownload:
+        skymap_paths = download_skymap(asi_array_code.lower(), location_code, redownload=redownload)
 
     else:
         # If the user does not want to force download skymap files,
@@ -233,7 +236,7 @@ def load_skymap(
         # Download skymap files if they are not downloaded yet.
         if len(skymap_paths) == 0:
             skymap_paths = download_skymap(
-                asi_array_code.lower(), location_code, force_download=force_download
+                asi_array_code.lower(), location_code, redownload=redownload
             )
 
     skymap_dates = _extract_skymap_dates(skymap_paths)
@@ -280,7 +283,7 @@ def _load_image(
     asi_array_code: str,
     location_code: str,
     time: utils._time_type,
-    force_download: bool = False,
+    redownload: bool = False,
     time_thresh_s: float = 3,
 ) -> Tuple[datetime, np.ndarray]:
     """
@@ -299,7 +302,7 @@ def _load_image(
         ISO 8601 standard.
     time_range: list of datetime.datetimes or stings
         Defined the duration of data to download. Must be of length 2.
-    force_download: bool
+    redownload: bool
         If True, download the file even if it already exists. Useful if a prior
         data download was incomplete.
     time_thresh_s: float
@@ -328,7 +331,7 @@ def _load_image(
     """
     time = utils._validate_time(time)
 
-    cdf_path = _find_img_path(asi_array_code, location_code, time, force_download=force_download)
+    cdf_path = _find_img_path(asi_array_code, location_code, time, redownload=redownload)
     cdf_obj = cdflib.CDF(cdf_path)
 
     if asi_array_code.lower() == 'rego':
@@ -356,7 +359,7 @@ def _load_images(
     asi_array_code: str,
     location_code: str,
     time_range: utils._time_range_type,
-    force_download: bool = False,
+    redownload: bool = False,
     ignore_missing_data: bool = True,
 ) -> Tuple[np.ndarray, np.ndarray]:
     """
@@ -373,7 +376,7 @@ def _load_images(
         The ASI station code, i.e. ``ATHA``
     time_range: list of datetime.datetimes or stings
         Defined the duration of data to download. Must be of length 2.
-    force_download: bool
+    redownload: bool
         If True, download the file even if it already exists. Useful if a prior
         data download was incomplete.
     time_thresh_s: float
@@ -418,7 +421,7 @@ def _load_images(
         asi_array_code,
         location_code,
         time_range,
-        force_download=force_download,
+        redownload=redownload,
         ignore_missing_data=ignore_missing_data,
     )
 
@@ -444,7 +447,7 @@ def _find_img_path(
     asi_array_code: str,
     location_code: str,
     time: utils._time_type,
-    force_download: bool = False,
+    redownload: bool = False,
 ) -> pathlib.Path:
     """
     Returns a path to an all sky full-resolution image (THEMIS:ASF, REGO:rgf) file.
@@ -459,7 +462,7 @@ def _find_img_path(
     time: datetime.datetime or str
         The date and time to download of the data. If str, ``time`` must be in the
         ISO 8601 standard.
-    force_download: bool
+    redownload: bool
         If True, download the file even if it already exists. Useful if a prior
         data download was incomplete.
 
@@ -488,9 +491,9 @@ def _find_img_path(
     """
     time = utils._validate_time(time)
 
-    if force_download:
+    if redownload:
         file_path = download_image(
-            asi_array_code.lower(), location_code, time=time, force_download=force_download
+            asi_array_code.lower(), location_code, time=time, redownload=redownload
         )[0]
     else:
         # If the user does not want to force a download, look for a file on the
@@ -508,7 +511,7 @@ def _find_img_path(
         elif len(matched_paths) == 0:  # No local file found
             try:
                 file_path = download_image(
-                    asi_array_code.lower(), location_code, time=time, force_download=force_download
+                    asi_array_code.lower(), location_code, time=time, redownload=redownload
                 )[0]
             except NotADirectoryError:
                 raise FileNotFoundError(
@@ -527,11 +530,13 @@ def _get_epoch(cdf_obj, time_key, hour_date_time, asi_array_code, location_code)
     try:
         epoch = np.array(cdflib.cdfepoch.to_datetime(cdf_obj.varget(time_key)))
     except ValueError as err:
-        if str(err) == 'read length must be non-negative or -1':
+        if ('read length must be non-negative or -1' in str(err)) or ('not found' in str(err)):
             raise ValueError(
                 str(err) + '\n\n ASI data is probably corrupted for '
-                f'time={hour_date_time}, asi_array_code={asi_array_code}, location_code={location_code}. '
-                'download the data again with force_download=True).'
+                f'time={hour_date_time}, asi_array_code={asi_array_code}, '
+                f'location_code={location_code}. This can happen when the '
+                f'download was interrupted. Try to redownload the data using '
+                f'redownload=True).'
             )
         else:
             raise
@@ -554,7 +559,10 @@ def _create_empty_data_arrays(asi_array_code, time_range, type):
         raise NotImplementedError
 
     time_range = utils._validate_time_range(time_range)
-    max_n_timestamps = int((time_range[1] - time_range[0]).total_seconds() / cadence_s)
+    # + 1 just in case. The THEMIS and REGO cadence is not
+    # always exactly 3 seconds, so in certain circumstances
+    # there may be one or two extra data points.
+    max_n_timestamps = int((time_range[1] - time_range[0]).total_seconds() / cadence_s) + 1
 
     if type.lower() == 'keogram':
         data_shape = (max_n_timestamps, img_size)
